@@ -234,7 +234,7 @@ gfu_common_system_shutdown(GError **error)
 #else
 	g_set_error_literal(error,
 			    FWUPD_ERROR,
-			    FWUPD_ERROR_INVALID_ARGS,
+			    FWUPD_ERROR_NOT_SUPPORTED,
 			    "No supported backend compiled in to perform the operation.");
 #endif
 	return val != NULL;
