@@ -135,36 +135,17 @@ static GtkWidget *
 gfu_main_guid_instance_id_new(const gchar *instance_id, const gchar *guid)
 {
 	GtkWidget *row = adw_action_row_new();
-	GtkWidget *label = gtk_label_new(NULL);
+	g_autofree gchar *guid_monospace = g_strdup_printf("<tt>%s</tt>", guid);
+
+	adw_preferences_row_set_title(ADW_PREFERENCES_ROW(row), guid_monospace);
+	adw_preferences_row_set_use_markup(ADW_PREFERENCES_ROW(row), TRUE);
+	adw_preferences_row_set_title_selectable(ADW_PREFERENCES_ROW(row), TRUE);
 
-	/* set title */
 	if (instance_id != NULL) {
 		g_autofree gchar *instance_id_safe = g_markup_escape_text(instance_id, -1);
-		adw_preferences_row_set_title(ADW_PREFERENCES_ROW(row), instance_id_safe);
-		gtk_widget_add_css_class(row, "monospace");
-	} else {
-		/* TRANSLATORS: this is when we don't know how the GUID was constructed */
-		g_autofree gchar *tmp = g_strdup_printf("<i>%s</i>", _("Plugin Defined"));
-		adw_preferences_row_set_title(ADW_PREFERENCES_ROW(row), tmp);
+		adw_action_row_set_subtitle(ADW_ACTION_ROW(row), instance_id_safe);
 	}
 
-	/* this probably isn't interesting for the user */
-	if (g_strcmp0(instance_id, "main-system-firmware") == 0)
-		gtk_widget_add_css_class(row, "dim-label");
-
-	/* add guid */
-	gtk_label_set_selectable(GTK_LABEL(label), TRUE);
-	gtk_label_set_text(GTK_LABEL(label), guid);
-	gtk_widget_add_css_class(label, "monospace");
-
-	/* try really hard not to wrap */
-	gtk_label_set_wrap(GTK_LABEL(label), TRUE);
-	gtk_label_set_wrap_mode(GTK_LABEL(label), PANGO_WRAP_WORD_CHAR);
-#if GTK_CHECK_VERSION(4, 6, 0)
-	gtk_label_set_natural_wrap_mode(GTK_LABEL(label), GTK_NATURAL_WRAP_NONE);
-#endif
-
-	adw_action_row_add_suffix(ADW_ACTION_ROW(row), label);
 	return row;
 }
 
@@ -174,11 +155,7 @@ gfu_main_update_guids(GfuMain *self, GPtrArray *guids, GPtrArray *instance_ids)
 	GtkWidget *w;
 	g_autoptr(GHashTable) guid_hash = NULL;
 
-	w = GTK_WIDGET(gtk_builder_get_object(self->builder, "group_guids"));
-	adw_preferences_group_set_title(ADW_PREFERENCES_GROUP(w),
-					/* TRANSLATORS: the ID that defines the mapping from device
-					 * to firmware stream */
-					ngettext("GUID", "GUIDs", guids->len));
+	w = GTK_WIDGET(gtk_builder_get_object(self->builder, "row_guids"));
 	gtk_widget_set_visible(w, guids->len > 0);
 
 	w = GTK_WIDGET(gtk_builder_get_object(self->builder, "listbox_guids"));
@@ -439,10 +416,10 @@ gfu_main_refresh_device_cb(gpointer user_data)
 	    "label_device_install_duration",
 	    gfu_common_seconds_to_string(fwupd_device_get_install_duration(self->device)));
 
-	gfu_main_set_device_flags(self, fwupd_device_get_flags(self->device));
 	gfu_main_update_guids(self,
 			      fwupd_device_get_guids(self->device),
 			      fwupd_device_get_instance_ids(self->device));
+	gfu_main_set_device_flags(self, fwupd_device_get_flags(self->device));
 
 	/* device can be verified immediately without hardware access */
 	if (fwupd_device_has_flag(self->device, FWUPD_DEVICE_FLAG_CAN_VERIFY) &&
